@@ -1212,6 +1212,7 @@ glade_register_widget(GType type,
 		      GladeFindInternalChildFunc find_internal_child)
 {
     GladeWidgetBuildData *data;
+    gpointer old_data;
 
     g_return_if_fail(g_type_is_a(type, GTK_TYPE_WIDGET));
 
@@ -1226,6 +1227,10 @@ glade_register_widget(GType type,
     data->build_children = build_children;
     data->find_internal_child = find_internal_child;
 
+    old_data = g_type_get_qdata (type, glade_build_data_id);
+    if (old_data)
+	    g_free (old_data);
+
     g_type_set_qdata(type, glade_build_data_id, data);
 }
 
@@ -1662,7 +1667,7 @@ glade_standard_build_widget(GladeXML *xml, GType widget_type,
 
 	glade_xml_handle_widget_prop(xml, widget, prop->name, prop->value);
     }
-    g_list_free(tmp);
+    g_list_free(deferred_props);
 
     g_array_set_size(props_array, 0);
     g_array_set_size(custom_props_array, 0);
